@@ -3,8 +3,10 @@ WRONGTYPE_MSG = "WRONGTYPE Operation against a key holding the wrong kind of val
 SYNTAX_ERROR_MSG = "ERR syntax error"
 SYNTAX_ERROR_LIMIT_ONLY_WITH_MSG = (
     "ERR syntax error, LIMIT is only supported in combination with either BYSCORE or BYLEX")
+INVALID_HASH_MSG = "ERR hash value is not an integer"
 INVALID_INT_MSG = "ERR value is not an integer or out of range"
 INVALID_FLOAT_MSG = "ERR value is not a valid float"
+INVALID_WEIGHT_MSG = "ERR weight value is not a float"
 INVALID_OFFSET_MSG = "ERR offset is out of range"
 INVALID_BIT_OFFSET_MSG = "ERR bit offset is not an integer or out of range"
 INVALID_BIT_VALUE_MSG = "ERR bit is not an integer or out of range"
@@ -12,7 +14,7 @@ BITOP_NOT_ONE_KEY_ONLY = "ERR BITOP NOT must be called with a single source key"
 INVALID_DB_MSG = "ERR DB index is out of range"
 INVALID_MIN_MAX_FLOAT_MSG = "ERR min or max is not a float"
 INVALID_MIN_MAX_STR_MSG = "ERR min or max not a valid string range item"
-STRING_OVERFLOW_MSG = "ERR string exceeds maximum allowed size (512MB)"
+STRING_OVERFLOW_MSG = "ERR string exceeds maximum allowed size (proto-max-bulk-len)"
 OVERFLOW_MSG = "ERR increment or decrement would overflow"
 NONFINITE_MSG = "ERR increment would produce NaN or Infinity"
 SCORE_NAN_MSG = "ERR resulting score is not a number (NaN)"
@@ -20,15 +22,17 @@ INVALID_SORT_FLOAT_MSG = "ERR One or more scores can't be converted into double"
 SRC_DST_SAME_MSG = "ERR source and destination objects are the same"
 NO_KEY_MSG = "ERR no such key"
 INDEX_ERROR_MSG = "ERR index out of range"
-ZADD_NX_XX_ERROR_MSG = "ERR ZADD allows either 'nx' or 'xx', not both"
+INDEX_NEGATIVE_ERROR_MSG = "ERR value is out of range, must be positive"
+# ZADD_NX_XX_ERROR_MSG6 = "ERR ZADD allows either 'nx' or 'xx', not both"
+ZADD_NX_XX_ERROR_MSG = "ERR XX and NX options at the same time are not compatible"
 ZADD_INCR_LEN_ERROR_MSG = "ERR INCR option supports a single increment-element pair"
 ZADD_NX_GT_LT_ERROR_MSG = "ERR GT, LT, and/or NX options at the same time are not compatible"
 NX_XX_GT_LT_ERROR_MSG = "ERR NX and XX, GT or LT options at the same time are not compatible"
 EXPIRE_UNSUPPORTED_OPTION = "ERR Unsupported option {}"
-ZUNIONSTORE_KEYS_MSG = "ERR at least 1 input key is needed for ZUNIONSTORE/ZINTERSTORE"
+ZUNIONSTORE_KEYS_MSG = "ERR at least 1 input key is needed for {}"
 WRONG_ARGS_MSG7 = "ERR Wrong number of args calling Redis command from script"
 WRONG_ARGS_MSG6 = "ERR wrong number of arguments for '{}' command"
-UNKNOWN_COMMAND_MSG = "ERR unknown command '{}'"
+UNKNOWN_COMMAND_MSG = "ERR unknown command `{}`, with args beginning with: "
 EXECABORT_MSG = "EXECABORT Transaction discarded because of previous errors."
 MULTI_NESTED_MSG = "ERR MULTI calls can not be nested"
 WITHOUT_MULTI_MSG = "ERR {0} without MULTI"
