@@ -7,7 +7,7 @@ from fakeredis._command_args_parsing import extract_args
 from fakeredis._commands import (
     command, Key, Int, DbIndex, BeforeAny, CommandItem, SortFloat,
     delete_keys, key_value_type, )
-from fakeredis._helpers import compile_pattern, SimpleError, OK, casematch
+from fakeredis._helpers import (compile_pattern, SimpleError, OK, casematch)
 from fakeredis._zset import ZSet
 
 
